@@ -1,6 +1,6 @@
 ﻿'''_1582.py
 
-BearingStiffnessMatrixOption
+BearingCageMaterial
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_BEARING_STIFFNESS_MATRIX_OPTION = python_net_import('SMT.MastaAPI.Bearings', 'BearingStiffnessMatrixOption')
+_BEARING_CAGE_MATERIAL = python_net_import('SMT.MastaAPI.Bearings', 'BearingCageMaterial')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('BearingStiffnessMatrixOption',)
+__all__ = ('BearingCageMaterial',)
 
 
-class BearingStiffnessMatrixOption(Enum):
-    '''BearingStiffnessMatrixOption
+class BearingCageMaterial(Enum):
+    '''BearingCageMaterial
 
     This is a mastapy class.
 
@@ -26,13 +26,13 @@ class BearingStiffnessMatrixOption(Enum):
 
     @classmethod
     def type_(cls):
-        return _BEARING_STIFFNESS_MATRIX_OPTION
+        return _BEARING_CAGE_MATERIAL
 
     __hash__ = None
 
-    BASIC = 0
-    SPECIFY_MATRIX = 1
-    SPEED_DEPENDENT = 2
+    STEEL = 0
+    BRASS = 1
+    PLASTIC = 2
 
 
 def __enum_setattr(self, attr, value):
@@ -43,5 +43,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-BearingStiffnessMatrixOption.__setattr__ = __enum_setattr
-BearingStiffnessMatrixOption.__delattr__ = __enum_delattr
+BearingCageMaterial.__setattr__ = __enum_setattr
+BearingCageMaterial.__delattr__ = __enum_delattr
