@@ -1,6 +1,6 @@
 ﻿'''_1587.py
 
-JournalOilFeedType
+BearingModel
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_JOURNAL_OIL_FEED_TYPE = python_net_import('SMT.MastaAPI.Bearings', 'JournalOilFeedType')
+_BEARING_MODEL = python_net_import('SMT.MastaAPI.Bearings', 'BearingModel')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('JournalOilFeedType',)
+__all__ = ('BearingModel',)
 
 
-class JournalOilFeedType(Enum):
-    '''JournalOilFeedType
+class BearingModel(Enum):
+    '''BearingModel
 
     This is a mastapy class.
 
@@ -26,13 +26,17 @@ class JournalOilFeedType(Enum):
 
     @classmethod
     def type_(cls):
-        return _JOURNAL_OIL_FEED_TYPE
+        return _BEARING_MODEL
 
     __hash__ = None
 
-    AXIAL_GROOVE = 0
-    AXIAL_HOLE = 1
-    CIRCUMFERENTIAL_GROOVE = 2
+    CONCEPT_BEARING = 0
+    AXIAL_CLEARANCE_BEARING = 1
+    RADIAL_CLEARANCE_BEARING = 2
+    ROLLING_BEARING = 3
+    PLAIN_JOURNAL_BEARING = 4
+    TILTING_PAD_THRUST_BEARING = 5
+    TILTING_PAD_JOURNAL_BEARING = 6
 
 
 def __enum_setattr(self, attr, value):
@@ -43,5 +47,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-JournalOilFeedType.__setattr__ = __enum_setattr
-JournalOilFeedType.__delattr__ = __enum_delattr
+BearingModel.__setattr__ = __enum_setattr
+BearingModel.__delattr__ = __enum_delattr
