@@ -1,6 +1,6 @@
 ﻿'''_1590.py
 
-RatingLife
+BearingStiffnessMatrixOption
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_RATING_LIFE = python_net_import('SMT.MastaAPI.Bearings', 'RatingLife')
+_BEARING_STIFFNESS_MATRIX_OPTION = python_net_import('SMT.MastaAPI.Bearings', 'BearingStiffnessMatrixOption')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('RatingLife',)
+__all__ = ('BearingStiffnessMatrixOption',)
 
 
-class RatingLife(Enum):
-    '''RatingLife
+class BearingStiffnessMatrixOption(Enum):
+    '''BearingStiffnessMatrixOption
 
     This is a mastapy class.
 
@@ -26,24 +26,13 @@ class RatingLife(Enum):
 
     @classmethod
     def type_(cls):
-        return _RATING_LIFE
+        return _BEARING_STIFFNESS_MATRIX_OPTION
 
     __hash__ = None
 
-    _10 = 0
-    _5 = 1
-    _4 = 2
-    _3 = 3
-    _2 = 4
-    _1 = 5
-    _08 = 6
-    _06 = 7
-    _04 = 8
-    _02 = 9
-    _01 = 10
-    _008 = 11
-    _006 = 12
-    _005 = 13
+    BASIC = 0
+    SPECIFY_MATRIX = 1
+    SPEED_DEPENDENT = 2
 
 
 def __enum_setattr(self, attr, value):
@@ -54,5 +43,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-RatingLife.__setattr__ = __enum_setattr
-RatingLife.__delattr__ = __enum_delattr
+BearingStiffnessMatrixOption.__setattr__ = __enum_setattr
+BearingStiffnessMatrixOption.__delattr__ = __enum_delattr
