@@ -1,6 +1,6 @@
 ﻿'''_1597.py
 
-RotationalDirections
+OuterRingMounting
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_ROTATIONAL_DIRECTIONS = python_net_import('SMT.MastaAPI.Bearings', 'RotationalDirections')
+_OUTER_RING_MOUNTING = python_net_import('SMT.MastaAPI.Bearings', 'OuterRingMounting')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('RotationalDirections',)
+__all__ = ('OuterRingMounting',)
 
 
-class RotationalDirections(Enum):
-    '''RotationalDirections
+class OuterRingMounting(Enum):
+    '''OuterRingMounting
 
     This is a mastapy class.
 
@@ -26,13 +26,12 @@ class RotationalDirections(Enum):
 
     @classmethod
     def type_(cls):
-        return _ROTATIONAL_DIRECTIONS
+        return _OUTER_RING_MOUNTING
 
     __hash__ = None
 
-    CLOCKWISE = 0
-    ANTICLOCKWISE = 1
-    BIDIRECTIONAL = 2
+    STANDARD = 0
+    SPHERICAL = 1
 
 
 def __enum_setattr(self, attr, value):
@@ -43,5 +42,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-RotationalDirections.__setattr__ = __enum_setattr
-RotationalDirections.__delattr__ = __enum_delattr
+OuterRingMounting.__setattr__ = __enum_setattr
+OuterRingMounting.__delattr__ = __enum_delattr
