@@ -1,6 +1,6 @@
 ﻿'''_1242.py
 
-JointTypes
+HeadCapTypes
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_JOINT_TYPES = python_net_import('SMT.MastaAPI.Bolts', 'JointTypes')
+_HEAD_CAP_TYPES = python_net_import('SMT.MastaAPI.Bolts', 'HeadCapTypes')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('JointTypes',)
+__all__ = ('HeadCapTypes',)
 
 
-class JointTypes(Enum):
-    '''JointTypes
+class HeadCapTypes(Enum):
+    '''HeadCapTypes
 
     This is a mastapy class.
 
@@ -26,16 +26,12 @@ class JointTypes(Enum):
 
     @classmethod
     def type_(cls):
-        return _JOINT_TYPES
+        return _HEAD_CAP_TYPES
 
     __hash__ = None
 
-    SV1 = 0
-    SV2 = 1
-    SV3 = 2
-    SV4 = 3
-    SV5 = 4
-    SV6 = 5
+    HEXAGONAL_HEAD = 0
+    SOCKET_HEAD = 1
 
 
 def __enum_setattr(self, attr, value):
@@ -46,5 +42,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-JointTypes.__setattr__ = __enum_setattr
-JointTypes.__delattr__ = __enum_delattr
+HeadCapTypes.__setattr__ = __enum_setattr
+HeadCapTypes.__delattr__ = __enum_delattr
