@@ -1,6 +1,6 @@
 ﻿'''_1246.py
 
-StrengthGrades
+RolledBeforeOrAfterHeatTreament
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_STRENGTH_GRADES = python_net_import('SMT.MastaAPI.Bolts', 'StrengthGrades')
+_ROLLED_BEFORE_OR_AFTER_HEAT_TREAMENT = python_net_import('SMT.MastaAPI.Bolts', 'RolledBeforeOrAfterHeatTreament')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('StrengthGrades',)
+__all__ = ('RolledBeforeOrAfterHeatTreament',)
 
 
-class StrengthGrades(Enum):
-    '''StrengthGrades
+class RolledBeforeOrAfterHeatTreament(Enum):
+    '''RolledBeforeOrAfterHeatTreament
 
     This is a mastapy class.
 
@@ -26,14 +26,12 @@ class StrengthGrades(Enum):
 
     @classmethod
     def type_(cls):
-        return _STRENGTH_GRADES
+        return _ROLLED_BEFORE_OR_AFTER_HEAT_TREAMENT
 
     __hash__ = None
 
-    _129 = 0
-    _109 = 1
-    _88 = 2
-    OTHER = 3
+    ROLLED_BEFORE_HEAT_TREATMENT = 0
+    ROLLED_AFTER_HEAT_TREATMENT = 1
 
 
 def __enum_setattr(self, attr, value):
@@ -44,5 +42,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-StrengthGrades.__setattr__ = __enum_setattr
-StrengthGrades.__delattr__ = __enum_delattr
+RolledBeforeOrAfterHeatTreament.__setattr__ = __enum_setattr
+RolledBeforeOrAfterHeatTreament.__delattr__ = __enum_delattr
