@@ -1,6 +1,6 @@
 ﻿'''_1203.py
 
-NumberOfKeys
+KeyTypes
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_NUMBER_OF_KEYS = python_net_import('SMT.MastaAPI.DetailedRigidConnectors.KeyedJoints', 'NumberOfKeys')
+_KEY_TYPES = python_net_import('SMT.MastaAPI.DetailedRigidConnectors.KeyedJoints', 'KeyTypes')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('NumberOfKeys',)
+__all__ = ('KeyTypes',)
 
 
-class NumberOfKeys(Enum):
-    '''NumberOfKeys
+class KeyTypes(Enum):
+    '''KeyTypes
 
     This is a mastapy class.
 
@@ -26,12 +26,20 @@ class NumberOfKeys(Enum):
 
     @classmethod
     def type_(cls):
-        return _NUMBER_OF_KEYS
+        return _KEY_TYPES
 
     __hash__ = None
 
-    _1 = 0
-    _2 = 1
+    TYPE_A = 0
+    TYPE_B = 1
+    TYPE_AB = 2
+    TYPE_C = 3
+    TYPE_D = 4
+    TYPE_E = 5
+    TYPE_F = 6
+    TYPE_G = 7
+    TYPE_H = 8
+    TYPE_J = 9
 
 
 def __enum_setattr(self, attr, value):
@@ -42,5 +50,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-NumberOfKeys.__setattr__ = __enum_setattr
-NumberOfKeys.__delattr__ = __enum_delattr
+KeyTypes.__setattr__ = __enum_setattr
+KeyTypes.__delattr__ = __enum_delattr
