@@ -1,6 +1,6 @@
 ﻿'''_1168.py
 
-RootTypes
+Modules
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_ROOT_TYPES = python_net_import('SMT.MastaAPI.DetailedRigidConnectors.Splines', 'RootTypes')
+_MODULES = python_net_import('SMT.MastaAPI.DetailedRigidConnectors.Splines', 'Modules')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('RootTypes',)
+__all__ = ('Modules',)
 
 
-class RootTypes(Enum):
-    '''RootTypes
+class Modules(Enum):
+    '''Modules
 
     This is a mastapy class.
 
@@ -26,12 +26,27 @@ class RootTypes(Enum):
 
     @classmethod
     def type_(cls):
-        return _ROOT_TYPES
+        return _MODULES
 
     __hash__ = None
 
-    FLAT_ROOT = 0
-    FILLET_ROOT = 1
+    _025MM = 0
+    _05MM = 1
+    _06MM = 2
+    _075MM = 3
+    _08MM = 4
+    _1MM = 5
+    _125MM = 6
+    _15MM = 7
+    _175MM = 8
+    _2MM = 9
+    _25MM = 10
+    _3MM = 11
+    _4MM = 12
+    _5MM = 13
+    _6MM = 14
+    _8MM = 15
+    _10MM = 16
 
 
 def __enum_setattr(self, attr, value):
@@ -42,5 +57,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-RootTypes.__setattr__ = __enum_setattr
-RootTypes.__delattr__ = __enum_delattr
+Modules.__setattr__ = __enum_setattr
+Modules.__delattr__ = __enum_delattr
