@@ -1,6 +1,6 @@
 ﻿'''_1174.py
 
-FinishingMethods
+SAETorqueCycles
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_FINISHING_METHODS = python_net_import('SMT.MastaAPI.DetailedRigidConnectors.Splines', 'FinishingMethods')
+_SAE_TORQUE_CYCLES = python_net_import('SMT.MastaAPI.DetailedRigidConnectors.Splines', 'SAETorqueCycles')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('FinishingMethods',)
+__all__ = ('SAETorqueCycles',)
 
 
-class FinishingMethods(Enum):
-    '''FinishingMethods
+class SAETorqueCycles(Enum):
+    '''SAETorqueCycles
 
     This is a mastapy class.
 
@@ -26,12 +26,15 @@ class FinishingMethods(Enum):
 
     @classmethod
     def type_(cls):
-        return _FINISHING_METHODS
+        return _SAE_TORQUE_CYCLES
 
     __hash__ = None
 
-    GRINDING = 0
-    UNSPECIFIED = 1
+    _1000 = 3
+    _10000 = 4
+    _100000 = 5
+    _1000000 = 6
+    _10000000 = 7
 
 
 def __enum_setattr(self, attr, value):
@@ -42,5 +45,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-FinishingMethods.__setattr__ = __enum_setattr
-FinishingMethods.__delattr__ = __enum_delattr
+SAETorqueCycles.__setattr__ = __enum_setattr
+SAETorqueCycles.__delattr__ = __enum_delattr
