@@ -1,6 +1,6 @@
 ﻿'''_282.py
 
-ContactRatioRequirements
+ContactRatioDataSource
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_CONTACT_RATIO_REQUIREMENTS = python_net_import('SMT.MastaAPI.Gears', 'ContactRatioRequirements')
+_CONTACT_RATIO_DATA_SOURCE = python_net_import('SMT.MastaAPI.Gears', 'ContactRatioDataSource')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('ContactRatioRequirements',)
+__all__ = ('ContactRatioDataSource',)
 
 
-class ContactRatioRequirements(Enum):
-    '''ContactRatioRequirements
+class ContactRatioDataSource(Enum):
+    '''ContactRatioDataSource
 
     This is a mastapy class.
 
@@ -26,13 +26,12 @@ class ContactRatioRequirements(Enum):
 
     @classmethod
     def type_(cls):
-        return _CONTACT_RATIO_REQUIREMENTS
+        return _CONTACT_RATIO_DATA_SOURCE
 
     __hash__ = None
 
-    MAXIMISE = 0
-    CLOSE_TO_INTEGER = 1
-    IGNORE = 2
+    DESIGN = 0
+    OPERATING = 1
 
 
 def __enum_setattr(self, attr, value):
@@ -43,5 +42,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-ContactRatioRequirements.__setattr__ = __enum_setattr
-ContactRatioRequirements.__delattr__ = __enum_delattr
+ContactRatioDataSource.__setattr__ = __enum_setattr
+ContactRatioDataSource.__delattr__ = __enum_delattr
