@@ -1,6 +1,6 @@
 ﻿'''_296.py
 
-MicroGeometryInputTypes
+LubricationMethods
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_MICRO_GEOMETRY_INPUT_TYPES = python_net_import('SMT.MastaAPI.Gears', 'MicroGeometryInputTypes')
+_LUBRICATION_METHODS = python_net_import('SMT.MastaAPI.Gears', 'LubricationMethods')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('MicroGeometryInputTypes',)
+__all__ = ('LubricationMethods',)
 
 
-class MicroGeometryInputTypes(Enum):
-    '''MicroGeometryInputTypes
+class LubricationMethods(Enum):
+    '''LubricationMethods
 
     This is a mastapy class.
 
@@ -26,12 +26,14 @@ class MicroGeometryInputTypes(Enum):
 
     @classmethod
     def type_(cls):
-        return _MICRO_GEOMETRY_INPUT_TYPES
+        return _LUBRICATION_METHODS
 
     __hash__ = None
 
-    FACTORS = 0
-    MEASUREMENTS = 1
+    SPRAYINJECTION_LUBRICATION = 0
+    DIP_LUBRICATION = 1
+    SUBMERGED = 2
+    ADDITIONAL_SPRAY_LUBRICATION = 3
 
 
 def __enum_setattr(self, attr, value):
@@ -42,5 +44,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-MicroGeometryInputTypes.__setattr__ = __enum_setattr
-MicroGeometryInputTypes.__delattr__ = __enum_delattr
+LubricationMethods.__setattr__ = __enum_setattr
+LubricationMethods.__delattr__ = __enum_delattr
