@@ -1,6 +1,6 @@
 ﻿'''_297.py
 
-MicroGeometryModel
+MicroGeometryInputTypes
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_MICRO_GEOMETRY_MODEL = python_net_import('SMT.MastaAPI.Gears', 'MicroGeometryModel')
+_MICRO_GEOMETRY_INPUT_TYPES = python_net_import('SMT.MastaAPI.Gears', 'MicroGeometryInputTypes')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('MicroGeometryModel',)
+__all__ = ('MicroGeometryInputTypes',)
 
 
-class MicroGeometryModel(Enum):
-    '''MicroGeometryModel
+class MicroGeometryInputTypes(Enum):
+    '''MicroGeometryInputTypes
 
     This is a mastapy class.
 
@@ -26,13 +26,12 @@ class MicroGeometryModel(Enum):
 
     @classmethod
     def type_(cls):
-        return _MICRO_GEOMETRY_MODEL
+        return _MICRO_GEOMETRY_INPUT_TYPES
 
     __hash__ = None
 
-    NONE = 0
-    ESTIMATED_FROM_MACRO_GEOMETRY = 1
-    SPECIFIED_MICRO_GEOMETRY = 2
+    FACTORS = 0
+    MEASUREMENTS = 1
 
 
 def __enum_setattr(self, attr, value):
@@ -43,5 +42,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-MicroGeometryModel.__setattr__ = __enum_setattr
-MicroGeometryModel.__delattr__ = __enum_delattr
+MicroGeometryInputTypes.__setattr__ = __enum_setattr
+MicroGeometryInputTypes.__delattr__ = __enum_delattr
