@@ -1,6 +1,6 @@
 ﻿'''_1062.py
 
-ConicalFlanks
+ActiveConicalFlank
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_CONICAL_FLANKS = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Conical', 'ConicalFlanks')
+_ACTIVE_CONICAL_FLANK = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Conical', 'ActiveConicalFlank')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('ConicalFlanks',)
+__all__ = ('ActiveConicalFlank',)
 
 
-class ConicalFlanks(Enum):
-    '''ConicalFlanks
+class ActiveConicalFlank(Enum):
+    '''ActiveConicalFlank
 
     This is a mastapy class.
 
@@ -26,13 +26,12 @@ class ConicalFlanks(Enum):
 
     @classmethod
     def type_(cls):
-        return _CONICAL_FLANKS
+        return _ACTIVE_CONICAL_FLANK
 
     __hash__ = None
 
-    CONCAVE = 0
-    CONVEX = 1
-    WORST = 2
+    DRIVE = 0
+    COAST = 1
 
 
 def __enum_setattr(self, attr, value):
@@ -43,5 +42,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-ConicalFlanks.__setattr__ = __enum_setattr
-ConicalFlanks.__delattr__ = __enum_delattr
+ActiveConicalFlank.__setattr__ = __enum_setattr
+ActiveConicalFlank.__delattr__ = __enum_delattr
