@@ -1,6 +1,6 @@
 ﻿'''_1074.py
 
-FrontEndTypes
+CutterGaugeLengths
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_FRONT_END_TYPES = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Conical', 'FrontEndTypes')
+_CUTTER_GAUGE_LENGTHS = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Conical', 'CutterGaugeLengths')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('FrontEndTypes',)
+__all__ = ('CutterGaugeLengths',)
 
 
-class FrontEndTypes(Enum):
-    '''FrontEndTypes
+class CutterGaugeLengths(Enum):
+    '''CutterGaugeLengths
 
     This is a mastapy class.
 
@@ -26,12 +26,12 @@ class FrontEndTypes(Enum):
 
     @classmethod
     def type_(cls):
-        return _FRONT_END_TYPES
+        return _CUTTER_GAUGE_LENGTHS
 
     __hash__ = None
 
-    FLAT = 0
-    CONICAL = 1
+    _1143MM = 0
+    _92075MM = 1
 
 
 def __enum_setattr(self, attr, value):
@@ -42,5 +42,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-FrontEndTypes.__setattr__ = __enum_setattr
-FrontEndTypes.__delattr__ = __enum_delattr
+CutterGaugeLengths.__setattr__ = __enum_setattr
+CutterGaugeLengths.__delattr__ = __enum_delattr
