@@ -1,31 +1,31 @@
 ﻿'''_981.py
 
-ISO6336GeometryBase
+ISO6336Geometry
 '''
 
 
 from mastapy._internal import constructor
-from mastapy import _0
+from mastapy.gears.gear_designs.cylindrical import _982
 from mastapy._internal.python_net import python_net_import
 
-_ISO6336_GEOMETRY_BASE = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical', 'ISO6336GeometryBase')
+_ISO6336_GEOMETRY = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical', 'ISO6336Geometry')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('ISO6336GeometryBase',)
+__all__ = ('ISO6336Geometry',)
 
 
-class ISO6336GeometryBase(_0.APIBase):
-    '''ISO6336GeometryBase
+class ISO6336Geometry(_982.ISO6336GeometryBase):
+    '''ISO6336Geometry
 
     This is a mastapy class.
     '''
 
-    TYPE = _ISO6336_GEOMETRY_BASE
+    TYPE = _ISO6336_GEOMETRY
 
     __hash__ = None
 
-    def __init__(self, instance_to_wrap: 'ISO6336GeometryBase.TYPE'):
+    def __init__(self, instance_to_wrap: 'ISO6336Geometry.TYPE'):
         super().__init__(instance_to_wrap)
         self._freeze()
 
@@ -48,13 +48,3 @@ class ISO6336GeometryBase(_0.APIBase):
         '''
 
         return self.wrapped.ISO6336RootFilletRadius
-
-    @property
-    def virtual_number_of_teeth(self) -> 'float':
-        '''float: 'VirtualNumberOfTeeth' is the original name of this property.
-
-        Note:
-            This property is readonly.
-        '''
-
-        return self.wrapped.VirtualNumberOfTeeth
