@@ -1,6 +1,6 @@
 ﻿'''_988.py
 
-MicroGeometryProfileConvention
+MicroGeometryConvention
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_MICRO_GEOMETRY_PROFILE_CONVENTION = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical', 'MicroGeometryProfileConvention')
+_MICRO_GEOMETRY_CONVENTION = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical', 'MicroGeometryConvention')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('MicroGeometryProfileConvention',)
+__all__ = ('MicroGeometryConvention',)
 
 
-class MicroGeometryProfileConvention(Enum):
-    '''MicroGeometryProfileConvention
+class MicroGeometryConvention(Enum):
+    '''MicroGeometryConvention
 
     This is a mastapy class.
 
@@ -26,14 +26,13 @@ class MicroGeometryProfileConvention(Enum):
 
     @classmethod
     def type_(cls):
-        return _MICRO_GEOMETRY_PROFILE_CONVENTION
+        return _MICRO_GEOMETRY_CONVENTION
 
     __hash__ = None
 
     MASTA_DEFAULT_MATERIAL = 0
     LDP = 1
-    ISOAGMADIN = 2
-    VDIVDE = 3
+    ISOAGMADINVDIVDE = 2
 
 
 def __enum_setattr(self, attr, value):
@@ -44,5 +43,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-MicroGeometryProfileConvention.__setattr__ = __enum_setattr
-MicroGeometryProfileConvention.__delattr__ = __enum_delattr
+MicroGeometryConvention.__setattr__ = __enum_setattr
+MicroGeometryConvention.__delattr__ = __enum_delattr
