@@ -1,31 +1,31 @@
 ﻿'''_761.py
 
-WheelFinishCutter
+PinionRoughCutter
 '''
 
 
 from mastapy._internal import constructor
-from mastapy.gears.gear_designs.conical import _1063
+from mastapy.gears.gear_designs.conical import _1065
 from mastapy._internal.python_net import python_net_import
 
-_WHEEL_FINISH_CUTTER = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Bevel.Cutters', 'WheelFinishCutter')
+_PINION_ROUGH_CUTTER = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Bevel.Cutters', 'PinionRoughCutter')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('WheelFinishCutter',)
+__all__ = ('PinionRoughCutter',)
 
 
-class WheelFinishCutter(_1063.ConicalGearCutter):
-    '''WheelFinishCutter
+class PinionRoughCutter(_1065.ConicalGearCutter):
+    '''PinionRoughCutter
 
     This is a mastapy class.
     '''
 
-    TYPE = _WHEEL_FINISH_CUTTER
+    TYPE = _PINION_ROUGH_CUTTER
 
     __hash__ = None
 
-    def __init__(self, instance_to_wrap: 'WheelFinishCutter.TYPE'):
+    def __init__(self, instance_to_wrap: 'PinionRoughCutter.TYPE'):
         super().__init__(instance_to_wrap)
         self._freeze()
 
