@@ -1,6 +1,6 @@
 ﻿'''_521.py
 
-LocationOfRootReliefEvaluation
+LocationOfEvaluationUpperLimit
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_LOCATION_OF_ROOT_RELIEF_EVALUATION = python_net_import('SMT.MastaAPI.Gears.MicroGeometry', 'LocationOfRootReliefEvaluation')
+_LOCATION_OF_EVALUATION_UPPER_LIMIT = python_net_import('SMT.MastaAPI.Gears.MicroGeometry', 'LocationOfEvaluationUpperLimit')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('LocationOfRootReliefEvaluation',)
+__all__ = ('LocationOfEvaluationUpperLimit',)
 
 
-class LocationOfRootReliefEvaluation(Enum):
-    '''LocationOfRootReliefEvaluation
+class LocationOfEvaluationUpperLimit(Enum):
+    '''LocationOfEvaluationUpperLimit
 
     This is a mastapy class.
 
@@ -26,13 +26,13 @@ class LocationOfRootReliefEvaluation(Enum):
 
     @classmethod
     def type_(cls):
-        return _LOCATION_OF_ROOT_RELIEF_EVALUATION
+        return _LOCATION_OF_EVALUATION_UPPER_LIMIT
 
     __hash__ = None
 
-    ROOT_FORM = 0
-    LOWER_EVALUATION_LIMIT = 1
-    USERSPECIFIED = 2
+    USERSPECIFIED = 0
+    TIP_FORM = 1
+    START_OF_TIP_RELIEF = 2
 
 
 def __enum_setattr(self, attr, value):
@@ -43,5 +43,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-LocationOfRootReliefEvaluation.__setattr__ = __enum_setattr
-LocationOfRootReliefEvaluation.__delattr__ = __enum_delattr
+LocationOfEvaluationUpperLimit.__setattr__ = __enum_setattr
+LocationOfEvaluationUpperLimit.__delattr__ = __enum_delattr
