@@ -1,6 +1,6 @@
 ﻿'''_207.py
 
-AGMAMaterialApplications
+AGMALubricantType
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_AGMA_MATERIAL_APPLICATIONS = python_net_import('SMT.MastaAPI.Materials', 'AGMAMaterialApplications')
+_AGMA_LUBRICANT_TYPE = python_net_import('SMT.MastaAPI.Materials', 'AGMALubricantType')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('AGMAMaterialApplications',)
+__all__ = ('AGMALubricantType',)
 
 
-class AGMAMaterialApplications(Enum):
-    '''AGMAMaterialApplications
+class AGMALubricantType(Enum):
+    '''AGMALubricantType
 
     This is a mastapy class.
 
@@ -26,12 +26,16 @@ class AGMAMaterialApplications(Enum):
 
     @classmethod
     def type_(cls):
-        return _AGMA_MATERIAL_APPLICATIONS
+        return _AGMA_LUBRICANT_TYPE
 
     __hash__ = None
 
-    GENERAL_APPLICATION = 0
-    CRITICAL_SERVICE = 1
+    MINERAL_OIL = 0
+    PAO_BASED_SYNTHETIC_NONVI_IMPROVED_OIL = 1
+    PAG_BASED_SYNTHETIC = 2
+    MILL7808K_GRADE_3 = 3
+    MILL7808K_GRADE_4 = 4
+    MILL23699E = 5
 
 
 def __enum_setattr(self, attr, value):
@@ -42,5 +46,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-AGMAMaterialApplications.__setattr__ = __enum_setattr
-AGMAMaterialApplications.__delattr__ = __enum_delattr
+AGMALubricantType.__setattr__ = __enum_setattr
+AGMALubricantType.__delattr__ = __enum_delattr
