@@ -1,6 +1,6 @@
 ﻿'''_227.py
 
-LubricantDelivery
+LubricantDefinition
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_LUBRICANT_DELIVERY = python_net_import('SMT.MastaAPI.Materials', 'LubricantDelivery')
+_LUBRICANT_DEFINITION = python_net_import('SMT.MastaAPI.Materials', 'LubricantDefinition')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('LubricantDelivery',)
+__all__ = ('LubricantDefinition',)
 
 
-class LubricantDelivery(Enum):
-    '''LubricantDelivery
+class LubricantDefinition(Enum):
+    '''LubricantDefinition
 
     This is a mastapy class.
 
@@ -26,13 +26,13 @@ class LubricantDelivery(Enum):
 
     @classmethod
     def type_(cls):
-        return _LUBRICANT_DELIVERY
+        return _LUBRICANT_DEFINITION
 
     __hash__ = None
 
-    SEALED = 0
-    SPLASH = 1
-    FEED = 2
+    STANDARD = 0
+    AGMA_925A03 = 1
+    VDI_27362014 = 2
 
 
 def __enum_setattr(self, attr, value):
@@ -43,5 +43,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-LubricantDelivery.__setattr__ = __enum_setattr
-LubricantDelivery.__delattr__ = __enum_delattr
+LubricantDefinition.__setattr__ = __enum_setattr
+LubricantDefinition.__delattr__ = __enum_delattr
