@@ -1,6 +1,6 @@
 ﻿'''_82.py
 
-ValueInputOption
+TransientSolverToleranceInputMethod
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_VALUE_INPUT_OPTION = python_net_import('SMT.MastaAPI.NodalAnalysis', 'ValueInputOption')
+_TRANSIENT_SOLVER_TOLERANCE_INPUT_METHOD = python_net_import('SMT.MastaAPI.NodalAnalysis', 'TransientSolverToleranceInputMethod')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('ValueInputOption',)
+__all__ = ('TransientSolverToleranceInputMethod',)
 
 
-class ValueInputOption(Enum):
-    '''ValueInputOption
+class TransientSolverToleranceInputMethod(Enum):
+    '''TransientSolverToleranceInputMethod
 
     This is a mastapy class.
 
@@ -26,15 +26,12 @@ class ValueInputOption(Enum):
 
     @classmethod
     def type_(cls):
-        return _VALUE_INPUT_OPTION
+        return _TRANSIENT_SOLVER_TOLERANCE_INPUT_METHOD
 
     __hash__ = None
 
-    CONSTANT = 0
-    VARYING_WITH_TIME = 1
-    VARYING_WITH_ANGLE = 2
-    VARYING_WITH_POSITION = 3
-    VARYING_WITH_ANGLE_AND_SPEED = 4
+    SIMPLE = 0
+    ADVANCED = 1
 
 
 def __enum_setattr(self, attr, value):
@@ -45,5 +42,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-ValueInputOption.__setattr__ = __enum_setattr
-ValueInputOption.__delattr__ = __enum_delattr
+TransientSolverToleranceInputMethod.__setattr__ = __enum_setattr
+TransientSolverToleranceInputMethod.__delattr__ = __enum_delattr
