@@ -1,6 +1,6 @@
 ﻿'''_83.py
 
-VolumeElementShape
+ValueInputOption
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_VOLUME_ELEMENT_SHAPE = python_net_import('SMT.MastaAPI.NodalAnalysis', 'VolumeElementShape')
+_VALUE_INPUT_OPTION = python_net_import('SMT.MastaAPI.NodalAnalysis', 'ValueInputOption')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('VolumeElementShape',)
+__all__ = ('ValueInputOption',)
 
 
-class VolumeElementShape(Enum):
-    '''VolumeElementShape
+class ValueInputOption(Enum):
+    '''ValueInputOption
 
     This is a mastapy class.
 
@@ -26,12 +26,15 @@ class VolumeElementShape(Enum):
 
     @classmethod
     def type_(cls):
-        return _VOLUME_ELEMENT_SHAPE
+        return _VALUE_INPUT_OPTION
 
     __hash__ = None
 
-    TETRAHEDRAL = 0
-    HEXAHEDRAL = 1
+    CONSTANT = 0
+    VARYING_WITH_TIME = 1
+    VARYING_WITH_ANGLE = 2
+    VARYING_WITH_POSITION = 3
+    VARYING_WITH_ANGLE_AND_SPEED = 4
 
 
 def __enum_setattr(self, attr, value):
@@ -42,5 +45,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-VolumeElementShape.__setattr__ = __enum_setattr
-VolumeElementShape.__delattr__ = __enum_delattr
+ValueInputOption.__setattr__ = __enum_setattr
+ValueInputOption.__delattr__ = __enum_delattr
