@@ -1,6 +1,6 @@
 ﻿'''_4012.py
 
-ParametricStudyDimension
+DoeValueSpecificationOption
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_PARAMETRIC_STUDY_DIMENSION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools', 'ParametricStudyDimension')
+_DOE_VALUE_SPECIFICATION_OPTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools', 'DoeValueSpecificationOption')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('ParametricStudyDimension',)
+__all__ = ('DoeValueSpecificationOption',)
 
 
-class ParametricStudyDimension(Enum):
-    '''ParametricStudyDimension
+class DoeValueSpecificationOption(Enum):
+    '''DoeValueSpecificationOption
 
     This is a mastapy class.
 
@@ -26,12 +26,13 @@ class ParametricStudyDimension(Enum):
 
     @classmethod
     def type_(cls):
-        return _PARAMETRIC_STUDY_DIMENSION
+        return _DOE_VALUE_SPECIFICATION_OPTION
 
     __hash__ = None
 
-    DIMENSION_1 = 1
-    DIMENSION_2 = 2
+    ABSOLUTE = 0
+    ADDITIVE = 1
+    NORMAL_DISTRIBUTION = 2
 
 
 def __enum_setattr(self, attr, value):
@@ -42,5 +43,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-ParametricStudyDimension.__setattr__ = __enum_setattr
-ParametricStudyDimension.__delattr__ = __enum_delattr
+DoeValueSpecificationOption.__setattr__ = __enum_setattr
+DoeValueSpecificationOption.__delattr__ = __enum_delattr
