@@ -1,6 +1,6 @@
 ﻿'''_2037.py
 
-FESubstructureType
+AlignmentMethod
 '''
 
 
@@ -8,15 +8,15 @@ from enum import Enum
 
 from mastapy._internal.python_net import python_net_import
 
-_FE_SUBSTRUCTURE_TYPE = python_net_import('SMT.MastaAPI.SystemModel.FE', 'FESubstructureType')
+_ALIGNMENT_METHOD = python_net_import('SMT.MastaAPI.SystemModel.FE', 'AlignmentMethod')
 
 
 __docformat__ = 'restructuredtext en'
-__all__ = ('FESubstructureType',)
+__all__ = ('AlignmentMethod',)
 
 
-class FESubstructureType(Enum):
-    '''FESubstructureType
+class AlignmentMethod(Enum):
+    '''AlignmentMethod
 
     This is a mastapy class.
 
@@ -26,16 +26,17 @@ class FESubstructureType(Enum):
 
     @classmethod
     def type_(cls):
-        return _FE_SUBSTRUCTURE_TYPE
+        return _ALIGNMENT_METHOD
 
     __hash__ = None
 
-    FULL_FE_MESH = 0
-    EXTERNALLY_REDUCED_FE = 1
-    CREATE_SHAFT_MESH = 2
-    IMPORTED_STL_MESH = 3
-    ANSYS_SPACECLAIM_GEOMETRY = 4
-    ANSYS_SPACECLAIM_FE_MESH = 5
+    AUTO = 0
+    MANUAL = 1
+    DATUM = 2
+    REPLACED_SHAFT = 3
+    SHAFT = 4
+    CONNECTABLE_COMPONENT = 5
+    COMPONENT = 6
 
 
 def __enum_setattr(self, attr, value):
@@ -46,5 +47,5 @@ def __enum_delattr(self, attr):
     raise AttributeError('Cannot delete the attributes of an Enum.') from None
 
 
-FESubstructureType.__setattr__ = __enum_setattr
-FESubstructureType.__delattr__ = __enum_delattr
+AlignmentMethod.__setattr__ = __enum_setattr
+AlignmentMethod.__delattr__ = __enum_delattr
